@@ -886,8 +886,10 @@ build_file_info (GVfsBackendGoogle      *self,
 {
   GFileType file_type;
   GList *authors;
+  GList *links;
   gboolean is_folder = FALSE;
   gboolean is_root = FALSE;
+  gboolean has_parent = FALSE;
   const gchar *etag;
   const gchar *id;
   const gchar *name;
@@ -907,7 +909,9 @@ build_file_info (GVfsBackendGoogle      *self,
   if (entry == self->root)
     is_root = TRUE;
 
-  g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_DELETE, !is_root);
+  links = gdata_entry_look_up_links (entry, GDATA_LINK_PARENT);
+  has_parent = (links != NULL);
+
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_RENAME, !is_root);
 
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE, is_folder);
@@ -916,6 +920,9 @@ build_file_info (GVfsBackendGoogle      *self,
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_STANDARD_IS_VOLATILE, is_symlink);
 
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_TRASH, FALSE);
+  g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_DELETE, !is_root && has_parent);
+
+  g_file_info_set_is_hidden (info, !has_parent);
 
   if (is_folder)
     {
@@ -1079,6 +1086,7 @@ build_file_info (GVfsBackendGoogle      *self,
   g_free (generated_copy_name);
   g_free (escaped_name);
   g_free (content_type);
+  g_list_free (links);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -1184,6 +1192,22 @@ g_vfs_backend_google_copy (GVfsBackend           *_self,
         }
     }
 
+  etag = gdata_entry_get_etag (source_entry);
+  id = gdata_entry_get_id (source_entry);
+  summary = gdata_entry_get_summary (source_entry);
+
+  /* Fail the job if copy/move operation leads to display name loss.
+   * Use G_IO_ERROR_FAILED instead of _NOT_SUPPORTED to avoid r/w fallback.
+   * See: https://bugzilla.gnome.org/show_bug.cgi?id=755701 */
+  if (g_strcmp0 (id, destination_basename) == 0)
+    {
+      g_vfs_job_failed_literal (G_VFS_JOB (job),
+                                G_IO_ERROR,
+                                G_IO_ERROR_FAILED,
+                                _("Operation unsupported"));
+      goto out;
+    }
+
   if (destination_not_directory)
     {
       g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_DIRECTORY, _("The file is not a directory"));
@@ -1222,10 +1246,6 @@ g_vfs_backend_google_copy (GVfsBackend           *_self,
         }
     }
 
-  etag = gdata_entry_get_etag (source_entry);
-  id = gdata_entry_get_id (source_entry);
-  summary = gdata_entry_get_summary (source_entry);
-
   source_entry_type = G_OBJECT_TYPE (source_entry);
   dummy_source_entry = g_object_new (source_entry_type,
                                      "etag", etag,
