@@ -43,6 +43,7 @@ typedef struct {
   GInputStream *stream;
 
   char *range;
+  goffset request_offset;
   goffset offset;
 
 } GVfsHttpInputStreamPrivate;
@@ -115,11 +116,11 @@ g_vfs_http_input_stream_ensure_request (GInputStream *stream)
       g_assert_no_error (error);
       priv->msg = soup_request_http_get_message (SOUP_REQUEST_HTTP (priv->req));
       priv->offset = 0;
-
-      if (priv->range)
-	soup_message_headers_replace (priv->msg->request_headers, "Range", priv->range);
     }
 
+  if (priv->range)
+    soup_message_headers_replace (priv->msg->request_headers, "Range", priv->range);
+
   return priv->req;
 }
 
@@ -328,7 +329,8 @@ read_send_callback (GObject      *object,
   ReadAfterSendData *rasd = g_task_get_task_data (task);
   GError *error = NULL;
 
-  if (!soup_request_send_finish (SOUP_REQUEST (object), result, &error))
+  priv->stream = soup_request_send_finish (SOUP_REQUEST (object), result, &error);
+  if (!priv->stream)
     {
       g_task_return_error (task, error);
       g_object_unref (task);
@@ -336,6 +338,14 @@ read_send_callback (GObject      *object,
     }
   if (!SOUP_STATUS_IS_SUCCESSFUL (priv->msg->status_code))
     {
+      if (priv->msg->status_code == SOUP_STATUS_REQUESTED_RANGE_NOT_SATISFIABLE)
+        {
+          g_input_stream_close (priv->stream, NULL, NULL);
+          g_task_return_int (task, 0);
+          g_clear_object (&priv->stream);
+          g_object_unref (task);
+          return;
+        }
       g_task_return_new_error (task,
 			       SOUP_HTTP_ERROR,
 			       priv->msg->status_code,
@@ -473,7 +483,7 @@ g_vfs_http_input_stream_seek (GSeekable     *seekable,
       if (content_length)
 	{
 	  type = G_SEEK_SET;
-	  offset = content_length - offset;
+	  offset = priv->request_offset + content_length + offset;
 	}
     }
 
@@ -509,6 +519,7 @@ g_vfs_http_input_stream_seek (GSeekable     *seekable,
 
     case G_SEEK_SET:
       priv->range = g_strdup_printf ("bytes=%"G_GUINT64_FORMAT"-", (guint64)offset);
+      priv->request_offset = offset;
       priv->offset = offset;
       break;
 
